@@ -13,6 +13,5 @@ functions for retrieving details of existing tasks on the Switch Automation Plat
 from .JourneyDefinitionTask import JourneyDefinitionTask
 from .JourneyRetrySupportTask import JourneyRetrySupportTask
 from .JourneyStepDefinitionTask import JourneyStepDefinitionTask
-from .JourneyTask import JourneyTask
 
-__all__ = ['JourneyDefinitionTask', 'JourneyRetrySupportTask', 'JourneyStepDefinitionTask', 'JourneyTask']
+__all__ = ['JourneyDefinitionTask', 'JourneyRetrySupportTask', 'JourneyStepDefinitionTask']
